@@ -1,5 +1,4 @@
 import dataclasses
-import hashlib
 import pathlib
 import sqlite3
 import tempfile
@@ -122,14 +121,8 @@ class SqliteDocumentPersistence(object):
 
     def __resolve_feature_value(self, feature):
         binary_value = sqlite3.Binary(msgpack.packb(feature.value, use_bin_type=True))
-        hash_value = int(hashlib.sha1(binary_value).hexdigest(), 16) % (10 ** 8)
-        result = self.cursor.execute(FEATURE_VALUE_LOOKUP, [hash_value]).fetchone()
-        new_row = [binary_value, hash_value, feature.single]
-
-        if result is None:
-            fvalue_id = self.cursor.execute(FEATURE_VALUE_INSERT, new_row).lastrowid
-        else:
-            fvalue_id = result[0]
+        new_row = [binary_value, None, feature.single]
+        fvalue_id = self.cursor.execute(FEATURE_VALUE_INSERT, new_row).lastrowid
         return fvalue_id
 
     def __insert_node(self, node: ContentNode, parent):
@@ -372,6 +365,8 @@ class SqliteDocumentPersistence(object):
 
         self.cursor.executemany("delete from cnp where cn_id=?", all_child_ids)
         self.cursor.executemany("delete from cn where id=?", all_child_ids)
+        self.cursor.executemany("delete from f_value where id in (select fvalue_id from f where cn_id=?)",
+                                all_child_ids)
         self.cursor.executemany("delete from f where cn_id=?", all_child_ids)
 
     def remove_all_features(self, node):
@@ -513,7 +508,8 @@ class PersistenceManager(object):
                         self.child_cache[node._parent_uuid].append(node)
                     else:
                         self.child_cache[node._parent_uuid].append(node)
-                        self.child_cache[node._parent_uuid] = sorted(self.child_cache[node._parent_uuid], key=lambda x: x.index)
+                        self.child_cache[node._parent_uuid] = sorted(self.child_cache[node._parent_uuid],
+                                                                     key=lambda x: x.index)
 
     def get_node(self, node_id):
 
