@@ -68,12 +68,12 @@ def simplify_node(node: ContentNode):
         "node_type": node.node_type,
         "features": [feature.to_dict() for feature in node.get_features()],
         "content": node.content,
-        "content_parts": node.content_parts,
-        "children": [simplify_node(child_node) for child_node in node.children]
+        "content_parts": node.get_content_parts(),
+        "children": [simplify_node(child_node) for child_node in node.get_children()]
     }
 
 
-def simplify_document(document: Document) -> 'dict':
+def simplify_document(document: Document) -> dict:
     """
 
     Args:
@@ -221,7 +221,7 @@ class AssistantTestHarness:
     """
 
     def __init__(self, assistant: Assistant, stores: List[DocumentStore], kodexa_metadata_path: str,
-                 metadata: AssistantMetadata):
+                 metadata: AssistantMetadata, content_provider=None):
         """
         Initialize the test harness
 
@@ -230,16 +230,18 @@ class AssistantTestHarness:
             stores: the list of stores (usually LocalDocumentStore) that we will use to monitor for events
             kodexa_metadata_path (str): the path to the kodexa.yml (or kodexa.json)
             metadata (AssistantMetadata): the assistant metadata to use for this assistant
+            content_provider: optional provider for content
         """
         self.assistant = assistant
         self.stores = stores
         self.kodexa_metadata_path = kodexa_metadata_path
         self.metadata = metadata
+        self.content_provider = content_provider
 
         for store in self.stores:
             store.register_listener(self)
 
-    def test_assistant_event(self, assistant_event: AssistantEvent) -> 'AssistantResponse':
+    def test_assistant_event(self, assistant_event: AssistantEvent) -> AssistantResponse:
         """
         Pass an assistant event into the assistant
 
@@ -247,11 +249,12 @@ class AssistantTestHarness:
         :return: the response from the event
         """
         from kodexa import AssistantContext
-        assistant_context = AssistantContext(self.metadata, self.kodexa_metadata_path, self.stores)
+        assistant_context = AssistantContext(self.metadata, self.kodexa_metadata_path, self.stores,
+                                             self.content_provider)
 
         return self.assistant.process_event(assistant_event, assistant_context)
 
-    def test_scheduled_event(self, scheduled_event: AssistantEvent) -> 'AssistantResponse':
+    def test_scheduled_event(self, scheduled_event: AssistantEvent) -> AssistantResponse:
         """
         Pass a scheduled event into the assistant
 
@@ -259,7 +262,8 @@ class AssistantTestHarness:
         :return: the response from the assistant
         """
         from kodexa import AssistantContext
-        assistant_context = AssistantContext(self.metadata, self.kodexa_metadata_path, self.stores)
+        assistant_context = AssistantContext(self.metadata, self.kodexa_metadata_path, self.stores,
+                                             self.content_provider)
 
         return self.assistant.process_event(scheduled_event, assistant_context)
 
@@ -313,7 +317,7 @@ class AssistantTestHarness:
         """
         pass
 
-    def get_store(self, event: ContentEvent) -> 'DocumentStore':
+    def get_store(self, event: ContentEvent) -> DocumentStore:
         """
         Get a document store for the event (based on the document family ID)
 
@@ -426,7 +430,7 @@ class ExtensionPackUtil:
         raise Exception("Unable to find the action " + action_slug)
 
     def get_assistant_test_harness(self, assistant_slug, assistant_metadata: AssistantMetadata, options=None,
-                                   stores=None) -> 'AssistantTestHarness':
+                                   stores=None) -> AssistantTestHarness:
         """Provides a local test harness that can be used to validate the functionality
         of an assistant in a test case
 
